2. Platform Support — setupjavax documentation

# 2. Platform Support

The supported Python versions are:

- Core syntax: Python2.7+, Python3.5+ - see [pythonids]

- Implementations: CPython, PyPy, IPython, Jython, IronPython - see [pythonids]

The supported platforms are:

- Linux, BSD, Unix/Solaris, OS-X, Cygwin, and Windows - see [platformids]

- x86, amd64, arm32/armhf, arm64/aarch64 - see [machineids]

Supported/Verified devices - see [machineids]:

- Notebooks, Workstations, and Server

- PMs and VMs - Hybrid Clouds and Container Stacks

- Windows-WSL

- RaspberryPI, Asus-TinkerBoard

For a complete list of supported platforms refer to ‘Prerequisites’, for current test status see ‘Tested OS and Python Implementations’.